@@ -58,7 +58,7 @@ intersphinx_mapping = {
     "tortoise": ("https://tortoise.github.io/", None),
     "piccolo": ("https://piccolo-orm.readthedocs.io/en/latest", None),
     "opentelemetry": ("https://opentelemetry-python.readthedocs.io/en/latest/", None),
-    "advanced-alchemy": ("https://docs.advanced-alchemy.litestar.dev/latest/", None),
+    "advanced-alchemy": ("https://advanced-alchemy.litestar.dev/latest/", None),
     "jinja2": ("https://jinja.palletsprojects.com/en/latest/", None),
     "trio": ("https://trio.readthedocs.io/en/stable/", None),
     "pydantic": ("https://docs.pydantic.dev/latest/", None),
@@ -357,8 +357,12 @@ def delayed_setup(app: Sphinx) -> None:
     When running linkcheck pydata_sphinx_theme causes a build failure, and checking
     the builder in the initial `setup` function call is not possible, so the check
     and extension setup has to be delayed until the builder is initialized.
+
+    When running gettext pydata_sphinx_theme causes a build failure by attempting to
+    write to the _static directory, resulting in a FileNotFoundError for missing files
+    like pygments.css. See: https://github.com/pydata/pydata-sphinx-theme/issues/1840
     """
-    if app.builder.name == "linkcheck":
+    if app.builder.name == "linkcheck" or app.builder.name == "gettext":
         return
 
     app.setup_extension("pydata_sphinx_theme")
