@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any, Callable, Literal
 
 from litestar.contrib.opentelemetry._utils import get_route_details_from_scope
 from litestar.contrib.opentelemetry.middleware import (
@@ -24,7 +24,7 @@ from opentelemetry.trace import Span, TracerProvider  # pyright: ignore
 if TYPE_CHECKING:
     from opentelemetry.metrics import Meter, MeterProvider
 
-    from litestar.types import Scope, Scopes
+    from litestar.types import AfterExceptionHookHandler, Scope, Scopes
 
 OpenTelemetryHookHandler = Callable[[Span, dict], None]
 
@@ -36,6 +36,9 @@ class OpenTelemetryConfig:
     Consult the [OpenTelemetry ASGI documentation](https://opentelemetry-python-contrib.readthedocs.io/en/latest/instrumentation/asgi/asgi.html) for more info about the configuration options.
     """
 
+    after_exception_hook_handler: AfterExceptionHookHandler | None = field(default=None)
+    """Callback which is called with the exception and the scope object for every exception raised."""
+
     scope_span_details_extractor: Callable[[Scope], tuple[str, dict[str, Any]]] = field(
         default=get_route_details_from_scope
     )
@@ -77,6 +80,8 @@ class OpenTelemetryConfig:
     OpenTelemetry supports excluding urls by passing an env in the format '{exclude_urls_env_key}_EXCLUDED_URLS'. With
     the default being ``LITESTAR_EXCLUDED_URLS``.
     """
+    exclude_spans: list[Literal["receive", "send"]] | None = None
+    """Optionally exclude HTTP send and/or receive spans from the trace."""
     scopes: Scopes | None = field(default=None)
     """ASGI scopes processed by the middleware, if None both ``http`` and ``websocket`` will be processed."""
     middleware_class: type[OpenTelemetryInstrumentationMiddleware] = field(
