@@ -18,6 +18,7 @@ from typing import (
     Tuple,
     Union,
     cast,
+    overload,
 )
 
 import msgspec
@@ -446,6 +447,12 @@ class Accept:
     def __iter__(self) -> Iterator[str]:
         return map(str, self._accepted_types)
 
+    @overload
+    def best_match(self, provided_types: List[str], default: None = None) -> Optional[str]: ...
+
+    @overload
+    def best_match(self, provided_types: List[str], default: str) -> str: ...
+
     def best_match(self, provided_types: List[str], default: Optional[str] = None) -> Optional[str]:
         """Find the best matching media type for the request.
 
