@@ -210,7 +210,7 @@ class DTOBackend:
         Returns:
             A ``BackendT`` class.
         """
-        struct_name = self._create_transfer_model_name(model_name)
+        struct_name = self.dto_factory.__schema_name__ or self._create_transfer_model_name(model_name)
 
         struct = _create_struct_for_field_definitions(
             model_name=struct_name,
