@@ -6,11 +6,14 @@ from litestar.handlers.websocket_handlers.listener import (
     websocket_listener,
 )
 from litestar.handlers.websocket_handlers.route_handler import WebsocketRouteHandler, websocket
+from litestar.handlers.websocket_handlers.stream import send_websocket_stream, websocket_stream
 
 __all__ = (
     "WebsocketListener",
     "WebsocketListenerRouteHandler",
     "WebsocketRouteHandler",
+    "send_websocket_stream",
     "websocket",
     "websocket_listener",
+    "websocket_stream",
 )
