@@ -44,13 +44,13 @@ if TYPE_CHECKING:
     from .asgi_types import ASGIApp
     from .callable_types import AnyCallable, ExceptionHandler
 
-Dependencies: TypeAlias = "Mapping[str, Union[Provide, AnyCallable]]"
-ExceptionHandlersMap: TypeAlias = "MutableMapping[Union[int, Type[Exception]], ExceptionHandler]"
-Middleware: TypeAlias = "Union[Callable[..., ASGIApp], DefineMiddleware, Iterator[Tuple[ASGIApp, Dict[str, Any]]], Type[MiddlewareProtocol]]"
+Dependencies: TypeAlias = "Mapping[str, Union[Provide, AnyCallable]]"  # noqa: UP007
+ExceptionHandlersMap: TypeAlias = "MutableMapping[Union[int, Type[Exception]], ExceptionHandler]"  # noqa: UP007
+Middleware: TypeAlias = "Union[Callable[..., ASGIApp], DefineMiddleware, Iterator[Tuple[ASGIApp, Dict[str, Any]]], Type[MiddlewareProtocol]]"  # noqa: UP007
 ParametersMap: TypeAlias = "Mapping[str, ParameterKwarg]"
-PathType: TypeAlias = "Union[Path, PathLike, str]"
-ResponseCookies: TypeAlias = "Union[Sequence[Cookie], Mapping[str, str]]"
-ResponseHeaders: TypeAlias = "Union[Sequence[ResponseHeader], Mapping[str, str]]"
+PathType: TypeAlias = "Union[Path, PathLike, str]"  # noqa: UP007
+ResponseCookies: TypeAlias = "Union[Sequence[Cookie], Mapping[str, str]]"  # noqa: UP007
+ResponseHeaders: TypeAlias = "Union[Sequence[ResponseHeader], Mapping[str, str]]"  # noqa: UP007
 Scopes: TypeAlias = "set[Literal[ScopeType.HTTP, ScopeType.WEBSOCKET]]"
 TypeDecodersSequence: TypeAlias = "Sequence[tuple[Callable[[Any], bool], Callable[[Any, Any], Any]]]"
 TypeEncodersMap: TypeAlias = "Mapping[Any, Callable[[Any], Any]]"
