@@ -9,7 +9,6 @@ from .predicates import (
     is_annotated_type,
     is_any,
     is_async_callable,
-    is_attrs_class,
     is_class_and_subclass,
     is_class_var,
     is_dataclass_class,
@@ -33,9 +32,9 @@ from .sync import AsyncIteratorWrapper, ensure_async_callable
 from .typing import get_origin_or_inner_type, make_non_optional_union
 
 __all__ = (
-    "ensure_async_callable",
     "AsyncIteratorWrapper",
     "deprecated",
+    "ensure_async_callable",
     "find_index",
     "get_enum_string_value",
     "get_name",
@@ -44,7 +43,6 @@ __all__ = (
     "is_annotated_type",
     "is_any",
     "is_async_callable",
-    "is_attrs_class",
     "is_class_and_subclass",
     "is_class_var",
     "is_dataclass_class",
