@@ -215,7 +215,7 @@ def test_get_logger_without_logging_config() -> None:
     with create_test_client(logging_config=None) as client:
         with pytest.raises(
             ImproperlyConfiguredException,
-            match="cannot call '.get_logger' without passing 'logging_config' to the Litestar constructor first",
+            match=r"cannot call '.get_logger' without passing 'logging_config' to the Litestar constructor first",
         ):
             client.app.get_logger()
 
@@ -479,7 +479,7 @@ def test_customizing_handler(
         assert type(root_logger_handler) is expected_root_logger_handler_class
 
         if type(root_logger_handler) is QueueHandler:
-            formatter = root_logger_handler.listener.handlers[0].formatter  # type: ignore[attr-defined]
+            formatter = root_logger_handler.listener.handlers[0].formatter  # type: ignore[attr-defined, union-attr]
         else:
             formatter = root_logger_handler.formatter
         if formatter is not None:
