@@ -1,8 +1,11 @@
 import logging
+import sys
 from dataclasses import dataclass
 from typing import TYPE_CHECKING, Any, Awaitable, Callable, List, cast
 
 import pytest
+from _pytest.capture import CaptureFixture
+from _pytest.logging import LogCaptureFixture
 from starlette.middleware.base import BaseHTTPMiddleware, RequestResponseEndpoint
 
 from litestar import Controller, Request, Response, Router, get, post
@@ -13,8 +16,6 @@ from litestar.testing import create_test_client
 if TYPE_CHECKING:
     from typing import Type
 
-    from _pytest.logging import LogCaptureFixture
-
     from litestar.types import ASGIApp, Receive, Scope, Send
 
 logger = logging.getLogger(__name__)
@@ -47,8 +48,7 @@ class MiddlewareWithArgsAndKwargs(BaseHTTPMiddleware):
 
     async def dispatch(  # type: ignore[empty-body, explicit-override, override]
         self, request: Request, call_next: Callable[[Request], Awaitable[Response]]
-    ) -> Response:
-        ...
+    ) -> Response: ...
 
 
 @pytest.mark.parametrize(
@@ -63,8 +63,7 @@ class MiddlewareWithArgsAndKwargs(BaseHTTPMiddleware):
 )
 def test_custom_middleware_processing(middleware: Any) -> None:
     @get(path="/")
-    def handler() -> None:
-        ...
+    def handler() -> None: ...
 
     with create_test_client(route_handlers=[handler], middleware=[middleware]) as client:
         app = client.app
@@ -76,9 +75,8 @@ def test_custom_middleware_processing(middleware: Any) -> None:
             unpacked_middleware.append(cur)
             cur = cast("ASGIApp", cur.app)  # pyright: ignore
         unpacked_middleware.append(cur)
-        assert len(unpacked_middleware) == 4
 
-        middleware_instance = unpacked_middleware[1]
+        middleware_instance, *_ = unpacked_middleware
 
         assert isinstance(
             middleware_instance,
@@ -94,7 +92,7 @@ def test_custom_middleware_processing(middleware: Any) -> None:
             assert middleware_instance.arg == 1
 
 
-def test_request_body_logging_middleware(caplog: "LogCaptureFixture") -> None:
+def test_request_body_logging_middleware(caplog: LogCaptureFixture, capsys: "CaptureFixture[str]") -> None:
     @dataclass
     class JSONRequest:
         name: str
@@ -105,13 +103,22 @@ def test_request_body_logging_middleware(caplog: "LogCaptureFixture") -> None:
     def post_handler(data: JSONRequest) -> JSONRequest:
         return data
 
-    with caplog.at_level(logging.INFO):
+    if sys.version_info < (3, 13):
+        with caplog.at_level(logging.INFO):
+            client = create_test_client(
+                route_handlers=[post_handler], middleware=[MiddlewareProtocolRequestLoggingMiddleware]
+            )
+            response = client.post("/", json={"name": "moishe zuchmir", "age": 40, "programmer": True})
+            assert response.status_code == 201
+            assert "test logging" in caplog.text
+    else:
         client = create_test_client(
             route_handlers=[post_handler], middleware=[MiddlewareProtocolRequestLoggingMiddleware]
         )
         response = client.post("/", json={"name": "moishe zuchmir", "age": 40, "programmer": True})
         assert response.status_code == 201
-        assert "test logging" in caplog.text
+        log = capsys.readouterr()
+        assert "test logging" in log.err
 
 
 def test_middleware_call_order() -> None:
