@@ -53,18 +53,6 @@ def test_token(
             "nope",
             "1",
         ),
-        (
-            "HS256",
-            "",
-        ),
-        (
-            None,
-            None,
-        ),
-        (
-            "HS256",
-            None,
-        ),
         (
             "",
             None,
@@ -84,7 +72,7 @@ def test_encode_validation(algorithm: str, secret: str) -> None:
         Token(
             sub="123",
             exp=(datetime.now(timezone.utc) + timedelta(seconds=30)),
-        ).encode(algorithm="nope", secret=secret)
+        ).encode(algorithm=algorithm, secret=secret)
 
 
 def test_decode_validation() -> None:
@@ -182,7 +170,7 @@ def test_strict_aud_with_multiple_audiences_raises(audience: str | list[str]) ->
         )
 
 
-@pytest.mark.parametrize("audience", ["foo", ["foo", "bar"]])
+@pytest.mark.parametrize("audience", ["foo", ["foo"]])
 def test_strict_aud_with_one_element_sequence(audience: str | list[str]) -> None:
     # when validating with strict audience, PyJWT requires that the 'audience' parameter
     # is passed as a string - one element lists are not allowed. Since we allow these
@@ -193,11 +181,39 @@ def test_strict_aud_with_one_element_sequence(audience: str | list[str]) -> None
         encoded,
         secret=secret,
         algorithm="HS256",
-        audience=["foo"],
+        audience=audience,
         strict_audience=True,
     )
 
 
+@pytest.mark.parametrize(
+    "audience",
+    [
+        pytest.param(None, id="None"),
+        pytest.param("foo", id="String"),
+        pytest.param("not-foo", id="InvalidAudience"),
+        pytest.param(["foo", "bar"], id="List"),
+    ],
+)
+def test_validate_audience(audience: str | list[str]) -> None:
+    secret = secrets.token_hex()
+    encoded = Token(exp=datetime.now() + timedelta(days=1), sub="foo", aud=["foo", "bar"]).encode(secret, "HS256")
+
+    def decode() -> None:
+        Token.decode(
+            encoded,
+            secret=secret,
+            algorithm="HS256",
+            audience=audience,
+        )
+
+    if audience != "not-foo":
+        decode()
+    else:
+        with pytest.raises(NotAuthorizedException):
+            decode()
+
+
 def test_custom_decode_payload() -> None:
     @dataclasses.dataclass
     class CustomToken(Token):
@@ -207,7 +223,7 @@ def test_custom_decode_payload() -> None:
             encoded_token: str,
             secret: str,
             algorithms: list[str],
-            issuer: list[str] | None = None,
+            issuer: str | Sequence[str] | None = None,
             audience: str | Sequence[str] | None = None,
             options: JWTDecodeOptions | None = None,
         ) -> Any:
@@ -222,3 +238,23 @@ def test_custom_decode_payload() -> None:
     _secret = secrets.token_hex()
     encoded = CustomToken(exp=datetime.now() + timedelta(days=1), sub="foo").encode(_secret, "HS256")
     assert CustomToken.decode(encoded, secret=_secret, algorithm="HS256").sub == "some-random-value"
+
+
+@pytest.mark.parametrize("issuer", [None, "text", ["list", "of", "values"]])
+def test_token_issuer(issuer: str | list[str] | None) -> None:
+    iss = issuer[0] if isinstance(issuer, list) else issuer
+    secret = secrets.token_hex()
+    encoded = Token(
+        exp=datetime.now() + timedelta(days=1),
+        sub="foo",
+        iss=iss,
+    ).encode(secret, "HS256")
+
+    token = Token.decode(
+        encoded,
+        secret=secret,
+        algorithm="HS256",
+        issuer=issuer,
+    )
+
+    assert token.iss == iss
